# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['dore',
 'dore.attribute',
 'dore.attribute.config',
 'dore.attribute.value_generators',
 'dore.attribute.value_generators.composite',
 'dore.attribute.value_generators.composite.config',
 'dore.attribute.value_generators.faker',
 'dore.attribute.value_generators.faker.config',
 'dore.attribute.value_generators.ref',
 'dore.attribute.value_generators.ref.config',
 'dore.attribute.value_generators.selector',
 'dore.attribute.value_generators.selector.config',
 'dore.attribute.value_generators.selector.random_selector',
 'dore.attribute.value_generators.selector.random_selector.config',
 'dore.attribute.value_generators.selector.round_robin_selector',
 'dore.attribute.value_generators.selector.round_robin_selector.config',
 'dore.cache',
 'dore.cache.pydict',
 'dore.cache.redis',
 'dore.config',
 'dore.context',
 'dore.datastore',
 'dore.datastore.config',
 'dore.engine',
 'dore.exceptions',
 'dore.manifest',
 'dore.model',
 'dore.model.config',
 'dore.protocol',
 'dore.protocol.elasticsearch',
 'dore.protocol.elasticsearch.config',
 'dore.protocol.elasticsearch.elasticsearch7',
 'dore.protocol.elasticsearch.elasticsearch8',
 'dore.protocol.mongodb',
 'dore.protocol.mongodb.config',
 'dore.protocol.mysql',
 'dore.protocol.mysql.config',
 'dore.protocol.postgresql',
 'dore.protocol.postgresql.config',
 'dore.utils',
 'dore.utils.file',
 'dore.utils.graph',
 'dore.utils.rand']

package_data = \
{'': ['*']}

install_requires = \
['Faker>=13.4.0',
 'PyPika>=0.48.9',
 'elasticsearch7>=7.17.2,<8',
 'elasticsearch8>=8.1.2,<9',
 'jsonschema>=4.6.1',
 'mysqlclient>=2.1.0',
 'progressbar2>=4.0.0',
 'psycopg>=3.0.11',
 'pymongo>=4.1.1',
 'pystache>=0.6.0',
 'redis>=4.3.3']

entry_points = \
{'console_scripts': ['dore = dore.__main__:main']}

setup_kwargs = {
    'name': 'dore',
    'version': '1.0.1',
    'description': 'Schema based fake data generator',
    'long_description': '# What is Dore?\n\nDore is a schema based fake data generation tool.\n\n# Why is it called Dore?\n\nNo particular reason. I just wanted to share my thoughts on how we should have spelt *door*. \n\n# What can you do with it?\n\nDore allows you to define the details of your target data in a config file, known as the **Manifest**, and Dore\ntakes care of generating this data for you. <br>\n\nWith Dore, you can:\n* Generate fake data for **multiple models across multiple protocols with complex schema dependencies with just a \n  single command**. <br>\n  For example, you can set up your entire database with data for all tables with FK/PK integrity constraints in a single \n  command.\n  \n  \n* Generate fake data with **dependencies between models regardless of the protocol**. <br> \n  For example, you can have a column in a MySQL table be dependent/have a FK relationship on a field in an \n  Elasticsearch index.\n  \n\n* Support for generating data for attributes that are **nested to arbitrary depth**. **Nested attributes can in turn be \n  dependent** or have their values derived from attributes of models in other protocols. <br>\n  For example, you can have a MongoDB \n  collection which has a field that derives its value from a row of a PostgreSQL table or another MongoDB collection\'s \n  doc.\n\n## Getting Started\n\n### Installation\n\n##### Optional: Create a virtual env and activate it.\n\n```shell\npython3 -m venv venv && source venv/bin/activate\n```\n\n#### Install Dore\n\n```shell\npip install dore\n```\n### Usage\n\n```shell\ndore --manifest /path/to/manifest.json --var1=val1 --var2=val2 ...\n```\n\n\n## Useful Links\n\n* [GitHub](https://github.com/bkn-dore/dore-py)\n* [Tutorial](./tutorial)\n* [Examples](./examples)\n* [Manifest Docs](https://github.com/bkn-dore/bkn-dore.github.io)\n\n## CLI Options\n`Dore` command supports the following cli args. Required options are specified with `**` next to them. \n\nDetails for each supported cli arg is mentioned in [further sections](#More on CLI options)\n\n| Option                       | Description                                                  | Values        |\n| -----------------------------|--------------------------------------------------------------|---------------|              \n| `--manifest`**               | Absolute path to [manifest](#manifest) file                  | /path/to/file |\n| `--seed`                     | [Seed Options](#seed)                                        | Integer       |\n| `--scale`                    | Scale Factor                                                 | Number        |\n| `--cache`                    | [Cache Options](#caching)                                    | redis / local |\n| `--drop-conflicting-models`  | [Conflict handling options](#handling-conflicts)             | -             |\n| `--var1=val1`, `--var2=val2` | Provide values for [Manifest variables](#Manifest Variables) | -             |\n\n# Terminology\n\nYou will come across these terms quite frequently in Dore\'s documentation:\n\n* **Protocol**: A protocol is an implementation of a system. For example, `mysql`, `mongodb`, `elasticsearch8` are \n  all protocols.\n  \n  \n* **Datastore**: A datastore usually represents a particular database, whether that\'s a database running within \n  a locally installed MySQL server, a remote Elasticsearch cluster that is running on your company\'s servers, or\n  a remote MongoDB database hosted by a cloud provider.\n  \n\n* **Model**: A model represents a set of structured data, called records. Models usually represent a Table in\n  SQL databases, a Collection in MongoDB, an Index in Elasticsearch, etc.\n  \n\n* **Attributes**: Models consist of a set of attributes. Attributes usually correspond to columns of a table in SQL \n  databases, fields of a collection in MongoDB, etc.\n  \n\n* **Manifest**: The manifest is a config you provide to Dore which contains details of the data that needs\n   to be generated. <br>\n  On a high level, the manifest has details about protocols, datastores, models, attributes. etc.\n  \nLet\'s drive these concepts home with a few examples:\n* A MySQL database `foo_db` has a table `bar_tbl` which has columns `a`, `b`, and `c`.\n    * Here, `mysql` is the **protocol**.\n    * `foo_db` is a **datastore**.\n    * `bar_tbl` is a **model**.\n    * The model has **attributes** `a`, `b`, and `c`.\n  \n    \n* A MongoDB database `foo_db` has a collection `bar_collection` which has docs with fields `a`, `b`, and `c`.\n    * Here, `mongodb` is the **protocol**.\n    * `foo_db` is a **datastore**.\n    * `bar_collection` is a **model**.\n    * The model has **attributes** `a`, `b`, and `c`.\n  \n  \n### Supported Protocols\n\nCurrently, Dore supports the following protocols.\n\n| NoSQL Protocols | SQL Protocols    |\n| ----------------|------------------|\n| Elasticsearch   | MySQL            |\n| MongoDB         | PostgreSQL       |\n  \n# Tutorial\n\nIf this is the first time you\'re using Dore, we recommend you check our [tutorial](./tutorial) out to get familiar with\nit. \n\nIn the tutorial, we go through a hands on exercise where we use Dore to generate data for a popular (and relatively \nnon trivial) database schema from scratch!\n\n## Examples\n\nThere are examples present in [examples](./examples) directory of this repo with instructions\non how to execute them. These can help you get started on creating your first manifest or can serve as a reference \nin case you\'re stuck.\n\n# More on CLI options\n\n### Manifest\n\nThe manifest is the core config that contains specifications about the target data.\n\nA detailed documentation for the *Manifest* is available here:\n* https://Dore-datagen.github.io/\n\n### Caching\nIn order to generate records for models that are dependent on other models, the dependent model\'s records are loaded \ninto cache to avoid repeated db calls (which can be quite slow). By default, Dore uses a local python dictionary based \ncache. But, you can make Dore work with other caches as well.\n\n#### Caching with Redis\nRun Dore with redis cache by using `--cache redis` argument while invoking Dore:\n```shell\n(dore-venv)$ dore \\\n  ...\n  --cache redis \\\n  --redis-host <redis-host> \\\n  --redis-port <redis-port> \\\n  ...\n```\n\n#### CLI Options for Redis caching\n\n| Options           | Description                              | Values                |\n| ----------------- | ---------------------------------------- | --------------------- |\n| --redis-host      | Host URL for the redis cluster           | `"127.0.0.1"`, ...    |\n| --redis-port      | Port on which redis server is listening  | `6379`, ...           |\n\n<br>\n\n\n### Handling Conflicts\nDore tries to create models and datastores based on what has been specified in the Manifest. Being mindful of how\nDore handles name conflicts is important.\n\n**!! WARNING !!**<br> \n**BE CAREFUL WHILE USING THIS AS IT DELETES MODELS FROM DATASTORE**\n\nDore\'s default behavior to fail on encountering model name conflicts can be altered by using the \n`--drop-conflicting-models` option.\n\nWhen this option is used, Dore **DROPS / DELETES** conflicting models in the \ndatastore and re-creates them.\n\n```shell\n(dore-venv)$ dore ... --drop-conflicting-models ...\n```\n<br>\n\n\n### Seed\nAt its core, Dore creates datastores, models, and generates data for models based on the manifest provided. \n\nEach record of a model is a set of values for attributes of the model. The value generated for an attribute\nis based on the specified generator type and quite a few of the generators have randomness associated with them \n(ex: `faker`, `randomSelector`, etc). Each Dore run results into different records being generated for the same\nmodel due to this inherent randomness.\n\nIn order to reproduce the outcomes/records of a previous run, you can specify the `--seed` arg while invoking\nDore. The seed value for each run is usually present in the output logs of a Dore run.\n\nFor example, if you invoked Dore, you would see something like the below in output logs:\n\n```shell\n# First invocation (without --seed flag)\n\n(dore-venv)$ dore ...\n\n# --- Logs ---\n\n# Get seed value from output logs\n# ... other logs ...\n[2022-08-08 10:04:58,164] [INFO] [config.Dore_config]: executing with seed [-4140708867]\n# ... other logs ...\n```\n\nYou can then invoke Dore with above seed value in any subsequent runs and reproduce the same records/outcomes as the one above.\n\n```shell\n# Second, Third, Nth invocation with --seed flag produces same results as first invocation.\n\n(dore-venv)$ dore ... --seed -4140708867 ...\n```\n',
    'author': 'Bhargav KN',
    'author_email': 'bhargavkn.1996@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bkn-dore/dore-py',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
